function [U,FreeDofs] = assemDir_QFE(Mesh,BdFlag,GHandle)

%   Copyright 2005-2005 Patrick Meury
%   SAM - Seminar for Applied Mathematics
%   ETH-Zentrum
%   CH-8092 Zurich, Switzerland

  % Intialize constants

  nCoordinates = size(Mesh.Coordinates,1);
  nEdges = size(Mesh.Edges,1);
  
  U = zeros(nCoordinates+nEdges,1);
  
    % Extract Dirichlet nodes
  
    DEdges = find(Mesh.BdFlags==BdFlag);
    DNodes = unique([Mesh.Edges(DEdges,1); Mesh.Edges(DEdges,2)]);
    
    % Compute midpoints of all edges
    
    MidPoints = 1/2*(Mesh.Coordinates(Mesh.Edges(DEdges,1),:) + ...
                     Mesh.Coordinates(Mesh.Edges(DEdges,2),:));
    
    % Compute Dirichlet boundary conditions
  
    U(DNodes) = GHandle(Mesh.Coordinates(DNodes,:));  
    U(DEdges+nCoordinates) = GHandle(MidPoints);

  
  % Compute set of free dofs
  
  FreeDofs = [setdiff(1:nCoordinates,DNodes) ...
              setdiff(1:nEdges,DEdges) + nCoordinates];
  
return