function A = assemMat_QFE(Mesh,EHandle,varargin)

%   Copyright 2005-2005 Patrick Meury & Kah Ling Sia
%   SAM - Seminar for Applied Mathematics
%   ETH-Zentrum
%   CH-8092 Zurich, Switzerland

  % Initialize constants
  
  nCoordinates = size(Mesh.Coordinates,1);
  nElements = size(Mesh.Elements,1);
  
  % Preallocate memory
  
  I = zeros(36*nElements,1);
  J = zeros(36*nElements,1);
  A = zeros(36*nElements,1);

  % Assemble element contributions
  
  loc = 1:36;
  for i = 1:nElements
     
    % Extract vertices of the current element
  
    vidx = Mesh.Elements(i,:);
    Vertices = Mesh.Coordinates(vidx,:);
    
    % Compute element contributions
    
    Aloc = EHandle(Vertices,varargin{:});
      
    % Extract global edge numbers
    
    idx = [vidx ...
           Mesh.Vert2Edge(Mesh.Elements(i,1),Mesh.Elements(i,2))+nCoordinates ...
           Mesh.Vert2Edge(Mesh.Elements(i,2),Mesh.Elements(i,3))+nCoordinates ...
           Mesh.Vert2Edge(Mesh.Elements(i,3),Mesh.Elements(i,1))+nCoordinates];
    
    % Add contributions to global matrix
    
    Iloc = idx(ones(6,1),:)';
    I(loc) = Iloc(:);
    
    Jloc = idx(ones(1,6),:);
    J(loc) = Jloc(:);
    
    A(loc) = Aloc(:); 
    loc = loc+36;
    
  end
  
  % Assign output arguments
  
  A = sparse(I,J,A);      

return